#! /usr/bin/env python3

# above is the shebang, which tells machine to use python to run this file

# import a tool that counts occurrences of things in python
from collections import Counter


# create a function -- a chunk of code that can be *called* multiple times
def wordcount(filepath):
    """
    This function, called wordcount, takes one argument, `filepath`,
    which is a path to plaintext data.

    It returns a Counter, with word frequencies in this filepath
    """
    # open the file (like double clicking on it)
    with open(filepath) as data:
        raw_text = data.read()
    # print the first 100 characters to screen
    print(raw_text)[:100]
    # make everything lowercase (i.e. normalise)
    lowered = raw_text.lower()
    # split text on spaces. is this reliable?
    wordlist = lowered.split(' ')
    # loop over each word, remove those that are not alphanumeric
    cleaned = [word for word in wordlist if word.strip().isalnum()]
    # perform the counting using the Counter class
    counted = Counter(cleaned)
    # return the wordcount data to us after we call this function
    return counted


# all we have done so far is *define* a function ...
# we haven't yet *called* it (i.e. run it). do it like this:
wordcounts = wordcount("some-plaintext-data.txt")
# have a look at what is inside
print(wordcounts)
# get count for a particular word
wordcounts["test"]
# show the 10 most common words
wordcounts.most_common(10)

# if we have time -- store the results of the analysis in results.txt
with open("results.txt", "w") as results_file:
    # loop over the words starting with most frequent
    # or, we could use sorted(wordcounts.most_common()) to alphabetise
    for word, count in wordcounts.most_common():
        # write the word and count to file, separated by a tab
        results_file.write(f"{word}\t{count}\n")
